@@ -13,13 +13,14 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+import datetime
 from itertools import islice
 
 import bottlenose
 from lxml import objectify, etree
 
 
-AMAZON_ASSOCIATES_BASE_URL = 'http://www.amazon.com/dp/'
+AMAZON_ASSOCIATES_BASE_URL = 'http://www.amazon.{region}/dp/'
 
 
 class AmazonException(Exception):
@@ -52,6 +53,12 @@ class NoMorePages(SearchException):
     pass
 
 
+class SimilartyLookupException(AmazonException):
+    """Similarty Lookup Exception.
+    """
+    pass
+
+
 class AmazonAPI(object):
     def __init__(self, aws_key, aws_secret, aws_associate_tag, region="US"):
         """Initialize an Amazon API Proxy.
@@ -67,11 +74,12 @@ class AmazonAPI(object):
             See keys of bottlenose.api.SERVICE_DOMAINS for options, which were
             CA, CN, DE, ES, FR, IT, JP, UK, US at the time of writing.
         """
-        self.api = bottlenose.Amazon(aws_key, aws_secret, aws_associate_tag,
-            Region=region)
+        self.api = bottlenose.Amazon(
+            aws_key, aws_secret, aws_associate_tag, Region=region)
         self.aws_associate_tag = aws_associate_tag
+        self.region = region
 
-    def lookup(self, **kwargs):
+    def lookup(self, ResponseGroup="Large", **kwargs):
         """Lookup an Amazon Product.
 
         :return:
@@ -79,7 +87,7 @@ class AmazonAPI(object):
             or a list of  :class:`~.AmazonProduct` instances if multiple
             items where returned.
         """
-        response = self.api.ItemLookup(ResponseGroup="Large", **kwargs)
+        response = self.api.ItemLookup(ResponseGroup=ResponseGroup, **kwargs)
         root = objectify.fromstring(response)
         if root.Items.Request.IsValid == 'False':
             code = root.Items.Request.Errors.Error.Code
@@ -90,11 +98,48 @@ class AmazonAPI(object):
             raise AsinNotFound("ASIN(s) not found: '{0}'".format(
                 etree.tostring(root, pretty_print=True)))
         if len(root.Items.Item) > 1:
-            return [AmazonProduct(item,
-                self.aws_associate_tag, self) for item in root.Items.Item]
+            return [
+                AmazonProduct(
+                    item,
+                    self.aws_associate_tag,
+                    self,
+                    region=self.region) for item in root.Items.Item
+            ]
         else:
             return AmazonProduct(
-                root.Items.Item, self.aws_associate_tag, self)
+                root.Items.Item,
+                self.aws_associate_tag,
+                self,
+                region=self.region
+            )
+
+    def similarity_lookup(self, ResponseGroup="Large", **kwargs):
+        """Similarty Lookup.
+
+        Returns up to ten products that are similar to all items
+        specified in the request.
+
+        Example:
+            >>> api.similarity_lookup(ItemId='B002L3XLBO,B000LQTBKI')
+        """
+        response = self.api.SimilarityLookup(
+            ResponseGroup=ResponseGroup, **kwargs)
+        root = objectify.fromstring(response)
+        if root.Items.Request.IsValid == 'False':
+            code = root.Items.Request.Errors.Error.Code
+            msg = root.Items.Request.Errors.Error.Message
+            raise SimilartyLookupException(
+                "Amazon Similarty Lookup Error: '{0}', '{1}'".format(
+                    code, msg))
+        return [
+            AmazonProduct(
+                item,
+                self.aws_associate_tag,
+                self.api,
+                region=self.region
+            )
+            for item in getattr(root.Items, 'Item', [])
+        ]
 
     def search(self, **kwargs):
         """Search.
@@ -165,7 +210,7 @@ class AmazonSearch(object):
         except NoMorePages:
             pass
 
-    def _query(self, **kwargs):
+    def _query(self, ResponseGroup="Large", **kwargs):
         """Query.
 
         Query Amazon search and check for errors.
@@ -173,7 +218,7 @@ class AmazonSearch(object):
         :return:
             An lxml root element.
         """
-        response = self.api.ItemSearch(ResponseGroup="Large", **kwargs)
+        response = self.api.ItemSearch(ResponseGroup=ResponseGroup, **kwargs)
         root = objectify.fromstring(response)
         if root.Items.Request.IsValid == 'False':
             code = root.Items.Request.Errors.Error.Code
@@ -186,11 +231,72 @@ class AmazonSearch(object):
         return root
 
 
+class AmazonBrowseNode(object):
+
+    def __init__(self, element):
+        self.element = element
+
+    @property
+    def id(self):
+        """Browse Node ID.
+
+        A positive integer that uniquely identifies a parent product category.
+
+        :return:
+            ID (integer)
+        """
+        if hasattr(self.element, 'BrowseNodeId'):
+            return int(self.element['BrowseNodeId'])
+        return None
+
+    @property
+    def name(self):
+        """Browse Node Name.
+
+        :return:
+            Name (string)
+        """
+        return getattr(self.element, 'Name', None)
+
+    @property
+    def is_category_root(self):
+        """Boolean value that specifies if the browse node is at the top of
+        the browse node tree.
+        """
+        return getattr(self.element, 'IsCategoryRoot', False)
+
+    @property
+    def ancestor(self):
+        """This browse node's immediate ancestor in the browse node tree.
+
+        :return:
+            The ancestor as an :class:`~.AmazonBrowseNode`, or None.
+        """
+        ancestors = getattr(self.element, 'Ancestors', None)
+        if hasattr(ancestors, 'BrowseNode'):
+            return AmazonBrowseNode(ancestors['BrowseNode'])
+        return None
+
+    @property
+    def ancestors(self):
+        """A list of this browse node's ancestors in the browse node tree.
+
+        :return:
+            List of :class:`~.AmazonBrowseNode` objects.
+        """
+        ancestors = []
+        node = self.ancestor
+        while node is not None:
+            ancestors.append(node)
+            node = node.ancestor
+        return ancestors
+
+
 class AmazonProduct(object):
     """A wrapper class for an Amazon product.
     """
 
-    def __init__(self, item, aws_associate_tag, api, *args):
+    def __init__(self, item, aws_associate_tag, api, *args, **kwargs):
         """Initialize an Amazon Product Proxy.
 
         :param item:
@@ -200,6 +306,13 @@ class AmazonProduct(object):
         self.aws_associate_tag = aws_associate_tag
         self.api = api
         self.parent = None
+        if 'region' in kwargs:
+            if kwargs['region'] != "US":
+                self.region = kwargs['region']
+            else:
+                self.region = "com"
+        else:
+            self.region = "com"
 
     def to_string(self):
         """Convert Item XML to string.
@@ -223,7 +336,7 @@ class AmazonProduct(object):
             Element or None.
         """
         elements = path.split('.')
-        parent = root or self.item
+        parent = root if root is not None else self.item
         for element in elements[:-1]:
             parent = getattr(parent, element, None)
             if parent is None:
@@ -247,6 +360,26 @@ class AmazonProduct(object):
         else:
             return None
 
+    def _safe_get_element_date(self, path, root=None):
+        """Safe get elemnent date.
+
+        Get element as datetime.date or None,
+        :param root:
+            Lxml element.
+        :param path:
+            String path (i.e. 'Items.Item.Offers.Offer').
+        :return:
+            datetime.date or None.
+        """
+        value = self._safe_get_element_text(path=path, root=root)
+        if value is not None:
+            try:
+                value = datetime.datetime.strptime(value, '%Y-%m-%d').date()
+            except ValueError:
+                value = None
+
+        return value
+
     @property
     def price_and_currency(self):
         """Get Offer Price and Currency.
@@ -302,10 +435,46 @@ class AmazonProduct(object):
             Offer URL (string).
         """
         return "{0}{1}/?tag={2}".format(
-            AMAZON_ASSOCIATES_BASE_URL,
+            AMAZON_ASSOCIATES_BASE_URL.format(region=self.region.lower()),
             self.asin,
             self.aws_associate_tag)
 
+    @property
+    def author(self):
+        """Author.
+
+        :return:
+            Author (string)
+        """
+        return self._safe_get_element_text('ItemAttributes.Author')
+
+    @property
+    def publisher(self):
+        """Publisher.
+
+        :return:
+            Publisher (string)
+        """
+        return self._safe_get_element_text('ItemAttributes.Publisher')
+
+    @property
+    def label(self):
+        """Label.
+
+        :return:
+            Label (string)
+        """
+        return self._safe_get_element_text('ItemAttributes.Label')
+
+    @property
+    def manufacturer(self):
+        """Manufacturer.
+
+        :return:
+            Manufacturer (string)
+        """
+        return self._safe_get_element_text('ItemAttributes.Manufacturer')
+
     @property
     def brand(self):
         """Brand.
@@ -324,6 +493,51 @@ class AmazonProduct(object):
         """
         return self._safe_get_element_text('ItemAttributes.ISBN')
 
+    @property
+    def eisbn(self):
+        """EISBN (The ISBN of eBooks).
+
+        :return:
+            EISBN (string)
+        """
+        return self._safe_get_element_text('ItemAttributes.EISBN')
+
+    @property
+    def binding(self):
+        """Binding.
+
+        :return:
+            Binding (string)
+        """
+        return self._safe_get_element_text('ItemAttributes.Binding')
+
+    @property
+    def publication_date(self):
+        """Pubdate.
+
+        :return:
+            Pubdate (datetime.date)
+        """
+        return self._safe_get_element_date('ItemAttributes.PublicationDate')
+
+    @property
+    def release_date(self):
+        """Release date .
+
+        :return:
+            Release date (datetime.date)
+        """
+        return self._safe_get_element_date('ItemAttributes.PublicationDate')
+
+    @property
+    def edition(self):
+        """Edition.
+
+        :return:
+            Edition (string)
+        """
+        return self._safe_get_element_text('ItemAttributes.Edition')
+
     @property
     def large_image_url(self):
         """Large Image URL.
@@ -387,8 +601,8 @@ class AmazonProduct(object):
         if ean is None:
             ean_list = self._safe_get_element_text('ItemAttributes.EANList')
             if ean_list:
-                ean = self._safe_get_element_text('EANListElement',
-                    root=ean_list[0])
+                ean = self._safe_get_element_text(
+                    'EANListElement', root=ean_list[0])
         return ean
 
     @property
@@ -402,8 +616,8 @@ class AmazonProduct(object):
         if upc is None:
             upc_list = self._safe_get_element_text('ItemAttributes.UPCList')
             if upc_list:
-                upc = self._safe_get_element_text('UPCListElement',
-                    root=upc_list[0])
+                upc = self._safe_get_element_text(
+                    'UPCListElement', root=upc_list[0])
         return upc
 
     @property
@@ -560,3 +774,16 @@ class AmazonProduct(object):
             if parent:
                 self.parent = self.api.lookup(ItemId=parent)
         return self.parent
+
+    @property
+    def browse_nodes(self):
+        """Browse Nodes.
+
+        :return:
+            A list of :class:`~.AmazonBrowseNode` objects.
+        """
+        root = self._safe_get_element('BrowseNodes')
+        if root is None:
+            return []
+
+        return [AmazonBrowseNode(child) for child in root.iterchildren()]
